% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sjPlotKfoldCV.R
\name{sjp.kfold_cv}
\alias{sjp.kfold_cv}
\title{Plot model fit from k-fold cross-validation}
\usage{
sjp.kfold_cv(data, formula, k = 5)
}
\arguments{
\item{data}{A data frame, used to split the data into \code{k} trainig-test-pairs.}

\item{formula}{A model formula, used to fit linear models (\code{\link[stats]{lm}})
over all \code{k} training data sets.}

\item{k}{Number of folds.}
}
\description{
This function plots the aggregated residuals of k-fold cross-validated
               models against the outcome. This allows to evaluate how the model performs
               according over- or underestimation of the outcome.
}
\details{
This function, first, generates \code{k} cross-validated test-training
           pairs (using the \code{\link[modelr]{crossv_kfold}}-function) and
           fits the same linear model, specified in the \code{formula}-argument,
           over all training data sets. \cr \cr
           Then, the quality measures Root Mean Squared Error (\emph{rmse}),
           R-squared and Mean Squared Error (\emph{mse}) for each model are 
           calculated. The average for each of these measures is returned 
           from this function. \cr \cr
           Finally, the test data is used to predict the outcome from all
           models that have been fit on the training data, and the residuals
           from all test data is plotted against the observed values (outcome)
           from the test data. This plot can be used to validate the model
           and see, whether it over- (residuals > 0) or underestimates 
           (residuals < 0) the model's outcome.
}
\note{
Currently, only linear models are supported.
}
\examples{
library(sjmisc)
data(efc)

sjp.kfold_cv(efc, neg_c_7 ~ e42dep + c172code + c12hour)
sjp.kfold_cv(mtcars, mpg ~.)

}

